%Model of damped SHM, starting from rest
function damped_SHM
T = 0.2;     %Period /s
x0 = 1;      %Displacement at t=0
k = 1/10;    %Damping constant y = k*w
fsize = 16;  %Fontsize for graphs
te = 0.15;   %Evaluate x,v,a at this example time /s

%Define times for plots
t = linspace(0,7*T,1000);

%Compute damped SHM
[xe,ve,ae,w,y,phi,A] = dshm(T,x0,k,te);
[x,v,a,w,y,phi,A] = dshm(T,x0,k,t);

%Plot displacement vs time
axes('fontsize',fsize); plot(t,x); grid on; box on;
hold on; plot(te,xe,'r*'); axis tight;
xlabel('time /s'); ylabel('Displacement /m'); 
title(['Damped SHM. At t=',num2str(te),'s, x=',num2str(xe,3),'m.']);
print( gcf,'damped SHM x vs t.png','-r300','-dpng'); clf;

%

%Plot velocity vs time
axes('fontsize',fsize); plot(t,v); grid on; box on;
hold on; plot(te,ve,'r*'); axis tight;
xlabel('time /s'); ylabel('Velocity /ms^{-1}'); 
title(['Damped SHM. At t=',num2str(te),'s, v=',num2str(ve,3),'m/s.']);
print( gcf,'damped SHM v vs t.png','-r300','-dpng'); clf;

%

%Plot velocity vs w*x
axes('fontsize',fsize); plot(w*x,v); grid on; box on; axis equal;
hold on; plot(w*x0,0,'g*'); plot(w*xe,ve,'r*');
xlabel('\omega * Displacement /m'); ylabel('Velocity /ms^{-1}'); 
title(['Damped SHM. At t=',num2str(te),'s, x=',num2str(xe,3),...
    'm, v=',num2str(ve,3),'m/s.']);
print( gcf,'damped SHM v vs wx.png','-r300','-dpng'); close(gcf);

%%

%Model of damped SHM a + w^2 * x + 2*y*v = 0
function [x,v,a,w,y,phi,A] = dshm(T,x0,k,t)

%Angular frequency and damping constant
w = (2*pi/T)/sqrt( 1 - k^2 );
y = k*w;

%Calculate phase shift and 'amplitude' A
phi = atan( y/sqrt( w^2 - y^2) );
A = x0/cos(phi);

%Define time, displacement, velocity and acceleration
x = A*exp(-y*t).*cos( t*sqrt( w^2 - y^2) - phi );
v = A*exp(-y*t).*( -y*cos( t*sqrt( w^2 - y^2) - phi ) -...
    sqrt( w^2 - y^2).*sin( t*sqrt( w^2 - y^2) - phi ) );
a = -(w^2)*x - 2*y*v;

%End of code
